@@ -1,38 +1,7 @@
-from asyncio import AbstractEventLoop, get_event_loop
-
-from aiohttp import ClientSession
+from payme_uz.requests import Requests
 
 
-class PaymeSubscribeCard:
-    def __init__(self, paycom_id: str, debug: bool = False, loop: AbstractEventLoop = None):
-        # Asyncio loop instance
-        if loop is None:
-            loop = get_event_loop()
-        self.loop = loop
-
-        # URL's
-        self.test_url: str = 'https://checkout.test.paycom.uz/api/'
-        self.pro_url: str = 'https://checkout.paycom.uz/api/'
-        self.__api_url: str = self.test_url if debug else self.pro_url
-
-        self.__paycom_id: str = paycom_id
-
-        self.__headers: dict = {
-            "X-Auth": self.__paycom_id,
-        }
-
-        self._session = ClientSession(loop=self.loop)
-
-    async def __requests(self, card_data: dict) -> dict:
-        """
-        Ma'lumotlarni yuborish uchun funksiya.
-
-        :param card_data: Karta maʼlumotlari oʻz ichiga oladi.
-        :return JSON:
-        """
-        async with self._session.post(url=self.__api_url, json=card_data, headers=self.__headers) as response:
-            return await response.json()
-
+class PaymeSubscribeCard(Requests):
     async def create(self, number: str, expire: str, save: bool) -> dict:
         """
         Yangi karta tokenini yaratish uchun funksiya.
@@ -56,7 +25,7 @@ class PaymeSubscribeCard:
                 "save": save,
             }
         }
-        return await self.__requests(card_data=data)
+        return await self._requests(card_data=data)
 
     async def get_verify_code(self, token: str) -> dict:
         """
@@ -74,7 +43,7 @@ class PaymeSubscribeCard:
                 "token": token,
             }
         }
-        return await self.__requests(card_data=data)
+        return await self._requests(card_data=data)
 
     async def verify(self, verify_code: int, token: str) -> dict:
         """
@@ -94,7 +63,7 @@ class PaymeSubscribeCard:
                 "code": verify_code
             }
         }
-        return await self.__requests(card_data=data)
+        return await self._requests(card_data=data)
 
     async def check(self, token: str) -> dict:
         """
@@ -112,7 +81,7 @@ class PaymeSubscribeCard:
                 "token": token,
             }
         }
-        return await self.__requests(card_data=data)
+        return await self._requests(card_data=data)
 
     async def remove(self, token: str) -> dict:
         """
@@ -130,7 +99,4 @@ class PaymeSubscribeCard:
                 "token": token,
             }
         }
-        return await self.__requests(card_data=data)
-
-    async def close(self):
-        await self._session.close()
+        return await self._requests(card_data=data)
